# -*- coding: utf-8 -*-
import os

def main():
    source(findFile("scripts", "skrooge_functions.py"))
    initAllPluginsAndOpenAllPages()

    type(waitForObject(":Untitled - skrooge_KTabBar"), "<Alt+F>")
    type(waitForObject(":Untitled [modified] - skrooge.File_KMenu"), "<Down>")
    type(waitForObject(":Untitled [modified] - skrooge.File_KMenu"), "<Down>")
    type(waitForObject(":Untitled [modified] - skrooge.File_KMenu"), "<Down>")
    type(waitForObject(":Untitled [modified] - skrooge.File_KMenu"), "<Down>")
    type(waitForObject(":Untitled [modified] - skrooge.File_KMenu"), "<Down>")
    type(waitForObject(":Untitled [modified] - skrooge.File_KMenu"), "<Down>")
    type(waitForObject(":Untitled [modified] - skrooge.File_KMenu"), "<Down>")
    sendEvent("QKeyEvent", waitForObject(":Untitled [modified] - skrooge.File_KMenu"), QEvent.KeyPress, 16777220, 13, 0, "\r", False, 1)
    waitForObject(":Print Preview.Next page_QToolButton")
    clickButton(":Print Preview.Next page_QToolButton")
    waitForObject(":Print Preview.Next page_QToolButton")
    clickButton(":Print Preview.Next page_QToolButton")
    waitForObject(":Print Preview.Next page_QToolButton")
    clickButton(":Print Preview.Next page_QToolButton")
    waitForObject(":Print Preview.Next page_QToolButton")
    clickButton(":Print Preview.Next page_QToolButton")
    waitForObject(":Print Preview.Next page_QToolButton")
    clickButton(":Print Preview.Next page_QToolButton")
    waitForObject(":Print Preview.Next page_QToolButton")
    clickButton(":Print Preview.Next page_QToolButton")
    waitForObject(":Print Preview.Next page_QToolButton")
    clickButton(":Print Preview.Next page_QToolButton")
    waitForObject(":Print Preview.Next page_QToolButton")
    clickButton(":Print Preview.Next page_QToolButton")
    waitForObject(":Print Preview.Next page_QToolButton")
    clickButton(":Print Preview.Next page_QToolButton")
    waitForObject(":Print Preview_QPrintPreviewDialog")
    sendEvent("QCloseEvent", ":Print Preview_QPrintPreviewDialog")
    type(waitForObject(":Untitled - skrooge_KTabBar"), "<Ctrl+P>")
    waitForObject(":Print.Cancel_QPushButton")
    clickButton(":Print.Cancel_QPushButton")

    waitForObject(":all_plugins.skg [modified] - skrooge_SKGMainPanel")
    sendEvent("QCloseEvent", ":all_plugins.skg [modified] - skrooge_SKGMainPanel")
